@@ -17,28 +17,30 @@ pub(super) fn is_newline_as_whitespace(is_pre: bool, flag: &Option<CharFlags>) -
             .unwrap_or(false)
 }
 
-pub(crate) enum CharFlags {
+pub(super) enum CharFlags {
     Newline,
 }
 
+type RenderingCharIndicesItem = (Option<CharFlags>, usize, char, usize);
+
 // This is used as wrapper for CharIndices.
 // If you want to consider newline or other character,
 // you should wrap with RenderingCharIndices.
-pub(crate) struct RenderingCharIndices<'a>(Peekable<CharIndices<'a>>);
+pub(super) struct RenderingCharIndices<'a>(Peekable<CharIndices<'a>>);
 
 impl<'a> RenderingCharIndices<'a> {
-    pub(crate) fn from_str(s: &'a str) -> Self {
+    pub(super) fn from_str(s: &'a str) -> Self {
         let chars = s.char_indices().peekable();
         RenderingCharIndices(chars)
     }
 
-    pub(crate) fn peek_char(&mut self) -> Option<char> {
+    pub(super) fn peek_char(&mut self) -> Option<char> {
         self.0.peek().map(|(_, c)| *c)
     }
 }
 
 impl<'a> Iterator for RenderingCharIndices<'a> {
-    type Item = (Option<CharFlags>, usize, char, usize);
+    type Item = RenderingCharIndicesItem;
 
     fn next(&mut self) -> Option<Self::Item> {
         let chars = &mut self.0;
@@ -53,21 +55,21 @@ impl<'a> Iterator for RenderingCharIndices<'a> {
 }
 
 // Reversed RenderingCharIndices.
-pub(crate) struct RevRenderingCharIndices<'a>(Peekable<Rev<CharIndices<'a>>>);
+pub(super) struct RevRenderingCharIndices<'a>(Peekable<Rev<CharIndices<'a>>>);
 
 impl<'a> RevRenderingCharIndices<'a> {
-    pub(crate) fn from_str(s: &'a str) -> Self {
+    pub(super) fn from_str(s: &'a str) -> Self {
         let chars = s.char_indices().rev().peekable();
         RevRenderingCharIndices(chars)
     }
 
-    pub(crate) fn peek_char(&mut self) -> Option<char> {
+    pub(super) fn peek_char(&mut self) -> Option<char> {
         self.0.peek().map(|(_, c)| *c)
     }
 }
 
 impl<'a> Iterator for RevRenderingCharIndices<'a> {
-    type Item = (Option<CharFlags>, usize, char, usize);
+    type Item = RenderingCharIndicesItem;
 
     fn next(&mut self) -> Option<Self::Item> {
         let chars = &mut self.0;
@@ -80,3 +82,37 @@ impl<'a> Iterator for RevRenderingCharIndices<'a> {
         }
     }
 }
+
+#[cfg(test)]
+mod test {
+    use super::*;
+
+    fn assert_chars<I: Iterator<Item = RenderingCharIndicesItem>>(input: &str, chars: I) {
+        for (flags, i, ch, len) in chars {
+            let expected = &input[i..i + len];
+            let actual = ch.to_string();
+            if expected != actual {
+                if matches!(flags, Some(CharFlags::Newline)) && actual == " " {
+                    continue;
+                }
+                panic!("actual = '{}', expect = '{}'", actual, expected);
+            }
+        }
+    }
+
+    #[test]
+    fn test_rendering_char_indices() {
+        let input = "Hello\nWorld Test";
+        let chars = RenderingCharIndices::from_str(input);
+
+        assert_chars(input, chars);
+    }
+
+    #[test]
+    fn test_rev_rendering_char_indices() {
+        let input = "Hello\nWorld Test";
+        let chars = RevRenderingCharIndices::from_str(input);
+
+        assert_chars(input, chars);
+    }
+}
