@@ -1,9 +1,7 @@
-use super::char::{CharFlags, RenderingCharIndices};
-use super::font::whitespace_width;
+use super::font_trait::Font;
 use super::img::ImageInputFormat;
-use crate::renderer::{calculate_text_width, draw_text_mut, get_glyph_rect, FontSetting};
+use crate::renderer::{draw_text_mut, FontSetting};
 use crate::Error;
-use ab_glyph::{FontArc, PxScaleFont, ScaleFont};
 use image::imageops::overlay;
 use image::{load_from_memory_with_format, DynamicImage, ImageBuffer, Rgba, RgbaImage};
 use imageproc::map::map_colors;
@@ -11,11 +9,6 @@ use std::path::Path;
 
 pub use image::ImageOutputFormat;
 
-pub(super) struct FontMetrics {
-    pub height: f32,
-    pub width: f32,
-}
-
 pub(super) struct Context {
     pub image: Option<RgbaImage>,
 }
@@ -33,55 +26,6 @@ impl Context {
         })
     }
 
-    pub fn text_extents(
-        &self,
-        text: &str,
-        font: PxScaleFont<&FontArc>,
-        setting: &FontSetting,
-    ) -> FontMetrics {
-        let mut chars = RenderingCharIndices::from_str(text);
-        let mut width = 0.;
-        while let Some((flags, _, ch, _)) = chars.next() {
-            let metrics = self.char_extents(ch, chars.peek_char(), &flags, font, setting);
-            width += metrics.width;
-        }
-
-        FontMetrics {
-            height: font.ascent() + font.descent(),
-            width,
-        }
-    }
-
-    pub fn char_extents(
-        &self,
-        cur_char: char,
-        next_char: Option<char>,
-        flags: &Option<CharFlags>,
-        font: PxScaleFont<&FontArc>,
-        setting: &FontSetting,
-    ) -> FontMetrics {
-        let rect = get_glyph_rect(cur_char, &font, setting);
-
-        let height = font.ascent() + font.descent();
-
-        if cur_char.is_whitespace() {
-            return FontMetrics {
-                height,
-                width: whitespace_width(setting.size),
-            };
-        }
-
-        FontMetrics {
-            height,
-            width: match rect {
-                Some(rect) => {
-                    calculate_text_width(cur_char, next_char, flags, &font, &rect, setting) as f32
-                }
-                None => 0.,
-            },
-        }
-    }
-
     pub fn draw_background_color(&mut self, rgba: Rgba<u8>) -> Result<(), Error> {
         let image = match &self.image {
             Some(image) => image,
@@ -112,7 +56,7 @@ impl Context {
         color: Rgba<u8>,
         x: u32,
         y: u32,
-        font: &FontArc,
+        font: &dyn Font,
         setting: &FontSetting,
         text: &str,
     ) -> Result<(), Error> {
@@ -142,6 +86,13 @@ impl Context {
         }
     }
 
+    pub(super) fn into_rgba(mut self) -> Result<RgbaImage, Error> {
+        match self.image.take() {
+            None => Err(Error::NullElement),
+            Some(img) => Ok(img),
+        }
+    }
+
     pub(super) fn encode(mut self, f: ImageOutputFormat) -> Result<Vec<u8>, Error> {
         match self.image.take() {
             None => Err(Error::NullElement),
