@@ -1,11 +1,11 @@
 use super::char::{CharFlags, RenderingCharIndices};
-use super::context::{Context, FontMetrics};
 use super::layout::TextArea;
-use crate::font::{match_font_family, whitespace_width, FontContext};
+use crate::font::{match_font_family, whitespace_width, FontMetrics};
+use crate::font_context::FontContext;
+use crate::font_trait::Font;
 use crate::renderer::FontSetting;
 use crate::style::{Style, WordBreak};
 use crate::Error;
-use ab_glyph::FontArc;
 use std::ops::Range;
 
 pub(super) struct Line {
@@ -14,6 +14,18 @@ pub(super) struct Line {
     pub(super) height: f32,
 }
 
+impl Line {
+    fn new(range: Range<usize>, width: f32, height: f32) -> Self {
+        assert!(!range.is_empty());
+
+        Line {
+            range,
+            width,
+            height,
+        }
+    }
+}
+
 pub(super) struct LineBreaker<'a> {
     pub(super) title: &'a str,
     pub(super) lines: Vec<Line>,
@@ -35,10 +47,9 @@ impl<'a> LineBreaker<'a> {
     // TODO: support hyphenation
     pub(super) fn break_text(
         &mut self,
-        context: &Context,
         width: f32,
         style: &Style,
-        font: &Option<FontArc>,
+        font: &Option<impl Font>,
         textarea: &TextArea,
         font_context: &FontContext,
     ) -> Result<(), Error> {
@@ -78,7 +89,6 @@ impl<'a> LineBreaker<'a> {
                     &flags,
                     font,
                     i..i + ch_len,
-                    context,
                     font_context,
                     &setting,
                 )?,
@@ -91,7 +101,6 @@ impl<'a> LineBreaker<'a> {
                             &flags,
                             font,
                             i..i + ch_len,
-                            context,
                             font_context,
                             &setting,
                         )
@@ -104,11 +113,11 @@ impl<'a> LineBreaker<'a> {
 
             if setting.is_pre && is_newline {
                 let start = range.end + ch_len;
-                self.lines.push(Line {
-                    range: range.start..range.end + ch_len,
-                    height: line_height,
-                    width: line_width,
-                });
+                self.lines.push(Line::new(
+                    range.start..range.end + ch_len,
+                    line_width,
+                    line_height,
+                ));
                 self.set_max_line_size(FontMetrics {
                     height: line_height,
                     width: line_width,
@@ -123,11 +132,12 @@ impl<'a> LineBreaker<'a> {
                     WordBreak::Normal => {
                         let end = range.end;
                         line_width -= word_width + whitespace_width;
-                        self.lines.push(Line {
-                            range: range.start..last_whitespace_idx,
-                            height: line_height,
-                            width: line_width,
-                        });
+                        // TODO: support overflow text when text can not be broken.
+                        self.lines.push(Line::new(
+                            range.start..last_whitespace_idx,
+                            line_width,
+                            line_height,
+                        ));
                         self.set_max_line_size(FontMetrics {
                             height: line_height,
                             width: line_width,
@@ -138,11 +148,7 @@ impl<'a> LineBreaker<'a> {
                     }
                     WordBreak::BreakAll => {
                         let start = range.end;
-                        self.lines.push(Line {
-                            range,
-                            height: line_height,
-                            width: line_width,
-                        });
+                        self.lines.push(Line::new(range, line_width, line_height));
                         self.set_max_line_size(FontMetrics {
                             height: line_height,
                             width: line_width,
@@ -175,11 +181,7 @@ impl<'a> LineBreaker<'a> {
         }
 
         if !range.is_empty() {
-            self.lines.push(Line {
-                range,
-                height: line_height,
-                width: line_width,
-            });
+            self.lines.push(Line::new(range, line_width, line_height));
             self.set_max_line_size(FontMetrics {
                 height: line_height,
                 width: line_width,
@@ -211,21 +213,19 @@ impl<'a> LineBreaker<'a> {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::context::Context;
-    use crate::font::FontContext;
+    use crate::font::test_utils::FontMock;
     use crate::layout::TextArea;
     use crate::style::WhiteSpace;
-    use ab_glyph::FontArc;
 
     #[test]
     fn test_break_test_with_whitespace() {
-        let width = 80u32;
-        let height = 50u32;
-        let context = Context::new(width, height);
+        let width = 130u32;
+        let _height = 50u32;
 
         let text = "Hello World, Hello World";
-        let font_size = 16.;
-        let font = FontArc::try_from_slice(include_bytes!("../../fonts/Mplus1-Black.ttf")).unwrap();
+        let font_size = 10.;
+
+        let font = FontMock;
 
         let mut textarea = TextArea::new();
         textarea.push_text(text);
@@ -239,7 +239,6 @@ mod tests {
         let mut line_breaker = LineBreaker::new(text);
         line_breaker
             .break_text(
-                &context,
                 width as f32,
                 &Style {
                     font_size,
@@ -267,13 +266,12 @@ mod tests {
 
     #[test]
     fn test_break_test_with_pre_line() {
-        let width = 80u32;
-        let height = 50u32;
-        let context = Context::new(width, height);
+        let width = 130u32;
+        let _height = 50u32;
 
         let text = "Test\nHello World, Hello\nWorld";
-        let font_size = 16.;
-        let font = FontArc::try_from_slice(include_bytes!("../../fonts/Mplus1-Black.ttf")).unwrap();
+        let font_size = 10.;
+        let font = FontMock;
 
         let mut textarea = TextArea::new();
         textarea.push_text(text);
@@ -287,7 +285,6 @@ mod tests {
         let mut line_breaker = LineBreaker::new(text);
         line_breaker
             .break_text(
-                &context,
                 width as f32,
                 &Style {
                     font_size,
@@ -316,13 +313,12 @@ mod tests {
 
     #[test]
     fn test_break_with_newline_as_whitespace() {
-        let width = 80u32;
-        let height = 50u32;
-        let context = Context::new(width, height);
+        let width = 130u32;
+        let _height = 50u32;
 
         let text = "Hello World,\nHello\nWorld";
-        let font_size = 16.;
-        let font = FontArc::try_from_slice(include_bytes!("../../fonts/Mplus1-Black.ttf")).unwrap();
+        let font_size = 10.;
+        let font = FontMock;
 
         let mut textarea = TextArea::new();
         textarea.push_text(text);
@@ -336,7 +332,6 @@ mod tests {
         let mut line_breaker = LineBreaker::new(text);
         line_breaker
             .break_text(
-                &context,
                 width as f32,
                 &Style {
                     font_size,
@@ -365,13 +360,12 @@ mod tests {
 
     #[test]
     fn test_break_with_split_text_newline() {
-        let width = 80u32;
-        let height = 50u32;
-        let context = Context::new(width, height);
+        let width = 130u32;
+        let _height = 50u32;
 
         let text = "Test\nHello World, Hello\nWorld";
-        let font_size = 16.;
-        let font = FontArc::try_from_slice(include_bytes!("../../fonts/Mplus1-Black.ttf")).unwrap();
+        let font_size = 10.;
+        let font = FontMock;
 
         let mut textarea = TextArea::new();
         textarea
@@ -395,7 +389,6 @@ mod tests {
         let mut line_breaker = LineBreaker::new(text);
         line_breaker
             .break_text(
-                &context,
                 width as f32,
                 &Style::default(),
                 &Some(font),
@@ -420,14 +413,13 @@ mod tests {
     #[test]
     fn test_break_test_with_char() {
         let width = 90u32;
-        let height = 50u32;
-        let context = Context::new(width, height);
+        let _height = 50u32;
 
         let text = "こんにちは世界、こんにちは世界";
         let mut textarea = TextArea::new();
         textarea.push_text(text);
 
-        let font = FontArc::try_from_slice(include_bytes!("../../fonts/Mplus1-Black.ttf")).unwrap();
+        let font = FontMock;
 
         let font_context = FontContext::new();
 
@@ -438,10 +430,9 @@ mod tests {
         let mut line_breaker = LineBreaker::new(text);
         line_breaker
             .break_text(
-                &context,
                 width as f32,
                 &Style {
-                    font_size: 16.,
+                    font_size: 10.,
                     word_break: WordBreak::BreakAll,
                     ..Style::default()
                 },
