@@ -1,15 +1,16 @@
 use crate::Error;
-use image::ImageError;
+use image::{ImageError, RgbaImage};
 
 use super::context::{Context, ImageOutputFormat};
-use super::element::{Element, Img, Line, Text};
-use super::font::{create_font, FontContext, FontIndexStore};
+use super::element::{Element, Fragment, Img, Text};
+use super::font::create_font;
+use super::font_context::{FontContext, FontIndexStore};
+use super::font_trait::Font;
 use super::glyph::Glyph;
 use super::img::ImageInputFormat;
 use super::layout::{SplitText, TextArea};
 use super::renderer::FontSetting;
 use super::style::{Style, WindowStyle};
-use ab_glyph::{Font, FontArc};
 use std::{cell::RefCell, ops::Range, path::Path, str};
 
 #[derive(Default)]
@@ -174,6 +175,10 @@ impl OGImageWriter {
         self.context.into_vec()
     }
 
+    pub fn into_rgba(self) -> Result<RgbaImage, Error> {
+        self.context.into_rgba()
+    }
+
     /// Return the encoded raw image data.
     pub fn encode(self, format: ImageOutputFormat) -> Result<Vec<u8>, Error> {
         self.context.encode(format)
@@ -187,11 +192,11 @@ impl OGImageWriter {
         fn render_text(
             text: &str,
             range: &mut Range<usize>,
-            font: &FontArc,
+            font: &dyn Font,
             context: &mut Context,
             current_width: &mut u32,
             style: &Style,
-            line: &Line,
+            fragment: &Fragment,
         ) -> Result<(), Error> {
             let next_text = &text[range.clone()];
 
@@ -204,17 +209,15 @@ impl OGImageWriter {
 
             context.draw_text(
                 style.color.as_image_rgba(),
-                line.rect.x + *current_width,
-                line.rect.y,
+                fragment.rect.x + *current_width,
+                fragment.rect.y,
                 font,
                 &setting,
                 next_text,
             )?;
 
             *range = range.end..range.end;
-            *current_width += context
-                .text_extents(next_text, font.as_scaled(style.font_size), &setting)
-                .width as u32;
+            *current_width += font.text_extents(next_text, &setting).width as u32;
 
             Ok(())
         }
@@ -222,14 +225,14 @@ impl OGImageWriter {
         let style = text_elm.style;
         let mut current_split_text: Option<&SplitText> = None;
         let mut current_glyph: Option<&Glyph> = None;
-        for line in &text_elm.lines {
-            let text = &text_elm.text[line.range.clone()];
+        for fragment in &text_elm.fragments {
+            let text = &text_elm.text[fragment.range.clone()];
             let mut range = 0..0;
             let mut current_width = 0;
             for (i, ch) in text.char_indices() {
                 let ch_len = ch.to_string().len();
                 let (split_text, glyph) = text_elm.textarea.get_glyphs_from_char_range(
-                    line.range.start + i..line.range.start + i + ch_len,
+                    fragment.range.start + i..fragment.range.start + i + ch_len,
                 );
                 let contained = match (split_text, glyph) {
                     (Some(split_text), Some(glyph)) => {
@@ -263,16 +266,16 @@ impl OGImageWriter {
                     match current_glyph {
                         Some(glyph) => match &glyph.font_index_store {
                             FontIndexStore::Global(idx) => {
-                                let mut context = &mut self.context;
+                                let context = &mut self.context;
                                 self.font_context.with(idx, |font| {
                                     render_text(
                                         text,
                                         &mut range,
                                         font,
-                                        &mut context,
+                                        context,
                                         &mut current_width,
                                         style,
-                                        line,
+                                        fragment,
                                     )
                                 })?;
                             }
@@ -288,7 +291,7 @@ impl OGImageWriter {
                                     &mut self.context,
                                     &mut current_width,
                                     style,
-                                    line,
+                                    fragment,
                                 )?;
                             }
                             FontIndexStore::Child(_) => match current_split_text {
@@ -300,7 +303,7 @@ impl OGImageWriter {
                                         &mut self.context,
                                         &mut current_width,
                                         style,
-                                        line,
+                                        fragment,
                                     )?,
                                     None => return Err(Error::NotFoundSpecifiedFontFamily),
                                 },
@@ -336,7 +339,7 @@ impl OGImageWriter {
                                     context,
                                     &mut current_width,
                                     style,
-                                    line,
+                                    fragment,
                                 )
                             })?;
                         }
@@ -352,7 +355,7 @@ impl OGImageWriter {
                                 &mut self.context,
                                 &mut current_width,
                                 style,
-                                line,
+                                fragment,
                             )?;
                         }
                         FontIndexStore::Child(_) => match current_split_text {
@@ -365,7 +368,7 @@ impl OGImageWriter {
                                         &mut self.context,
                                         &mut current_width,
                                         style,
-                                        line,
+                                        fragment,
                                     )?;
                                 }
                                 None => return Err(Error::NotFoundSpecifiedFontFamily),
